@@ -818,12 +818,12 @@ public final class UnifiedMailMessage extends MailMessage implements Delegatized
 
     @Override
     public int getAccountId() {
-        return delegatee.getAccountId();
+        return null == accountId ? delegatee.getAccountId() : accountId.intValue();
     }
 
     @Override
     public boolean containsAccountId() {
-        return delegatee.containsAccountId();
+        return null != accountId || delegatee.containsAccountId();
     }
 
     @Override
@@ -833,7 +833,7 @@ public final class UnifiedMailMessage extends MailMessage implements Delegatized
 
     @Override
     public void setAccountId(final int accountId) {
-        delegatee.setAccountId(accountId);
+        this.accountId = Integer.valueOf(accountId);
     }
 
     @Override
